#ifndef PG862USB_H
#define PG862USB_H

#ifdef PG862USB_Exports
#define PG862USB_API __declspec(dllexport)
#else
#define PG862USB_API __declspec(dllimport)
#endif

extern "C"
 {
//Open device named as "PG-862":
//returns true if device opens correctly.
  PG862USB_API bool WINAPI PG862_OpenDevice(void);

//Close device:
//returns true if device closes correctly.
  PG862USB_API bool WINAPI PG862_CloseDevice(void);

//Get last error name:
//returns pointer to last error name string
//(empty string if error not occured).
  PG862USB_API void WINAPI PG862_GetLastError(LPCSTR &lpcStr);

//Get device info:
//returns pointer to device name string.
//Device name string is "PG-862 V1.0", where
//"PG-862" is device name, "V1.0" is firmware version
//(may be different).
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_GetInfo(LPCSTR &lpcStr);

//Set device control mode:
//bit mode.0 - device local control (encoder and pushbuttons) lock
//mode.0 = 0 - device local control is unlocked
//mode.0 = 1 - device local control is locked
//bit mode.1 - PG862_SetPar command sound signal on/off
//mode.1 = 0 - sound is on
//mode.1 = 1 - sound is off
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_SetMode(int mode);

//Read current device control mode:
//bit mode.0 - device local control (encoder and pushbuttons) lock
//mode.0 = 0 - device local control is unlocked
//mode.0 = 1 - device local control is locked
//bit mode.1 - PG862_SetPar command sound signal on/off
//mode.1 = 0 - sound is on
//mode.1 = 1 - sound is off
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_GetMode(int &mode);

//Set parameter value:
//n - parameter number (0..PARAMS - 1)
//ch - channel number (0..CHANS - 1)
//par - parameter value (see params ranges below)
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_SetPar(int n, int ch, int par);

//Read parameter value:
//n - parameter number (0..PARAMS - 1)
//ch - channel number (0..CHANS - 1)
//par - parameter value
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_GetPar(int n, int ch, int &par);

//Read selected parameter value:
//n - selected parameter number
//ch - selected channel number
//par - selected parameter value
//Returns true if device responds correctly.
  PG862USB_API bool WINAPI PG862_GetSelPar(int &n, int &ch, int &par);
 }

//Channels numbers:
enum { CHAN_A,   //channel A
       CHAN_B,   //channel B
       CHANS };  //cannels count

//Params numbers and ranges:
enum { PAR_T,    //pulse duration,  range 1..99999999910nS
       PAR_P,    //period,          range 2..99999999910nS
       PAR_D,    //delay,           range 0..99999999910nS
       PAR_E,    //dead time,       range 0..99999999910nS
       PAR_A,    //pulse amplitude, range -1500..150010mV
       PAR_S,    //pulse shift,     range -500..100010mV
       PAR_H,    //pulse shape,     range 0..4
       PAR_Y,    //sync type,       range 0..3
       PAR_L,    //sync level,      range 0..30010mV
       PARAMS }; //params count

//Pulse shape codes:
enum { SH_P,     //output pulse is active high (positive logic)
       SH_N,     //output pulse is active low (negative logic)
       SH_M,     //output is meander type
       SH_L,     //output static level is low
       SH_H,     //output static level is high
       SH_Z };   //output is disabled (Z-state)

//Sync type codes:
enum { SYNC_A,   //internal synchronization A
       SYNC_B,   //internal synchronization B
       SYNC_R,   //external synchronization, rising edge
       SYNC_F }; //external synchronization, falling edge

#endif


